@@ -30,9 +30,11 @@
 #include "proctable.h"
 #include "util.h"
 #include "procactions.h"
+#include "procman.h"
 #include "procdialogs.h"
 #include "memmaps.h"
 #include "openfiles.h"
+#include "procproperties.h"
 #include "load-graph.h"
 #include "disks.h"
 #include "lsof.h"
@@ -82,11 +84,26 @@ cb_edit_preferences (GtkAction *action, gpointer data)
 
 
 void
-cb_renice (GtkAction *action, gpointer data)
+cb_renice (GtkAction *action, GtkRadioAction *current, gpointer data)
 {
     ProcData * const procdata = static_cast<ProcData*>(data);
 
-    procdialog_create_renice_dialog (procdata);
+    gint selected = gtk_radio_action_get_current_value(current);
+
+    if (selected == CUSTOM_PRIORITY)
+    {
+       procdialog_create_renice_dialog (procdata);
+    } else {
+       gint new_nice_value = 0;
+       switch (selected) {
+           case VERY_HIGH_PRIORITY: new_nice_value = -20; break;
+           case HIGH_PRIORITY: new_nice_value = -5; break;
+           case NORMAL_PRIORITY: new_nice_value = 0; break;
+           case LOW_PRIORITY: new_nice_value = 5; break;
+           case VERY_LOW_PRIORITY: new_nice_value = 19; break;
+       }
+       renice(procdata, new_nice_value);
+    }
 }
 
 
@@ -116,10 +133,17 @@ void
 cb_show_open_files (GtkAction *action, gpointer data)
 {
     ProcData *procdata = static_cast<ProcData*>(data);
-    
+
     create_openfiles_dialog (procdata);
 }
 
+void
+cb_show_process_properties (GtkAction *action, gpointer data)
+{
+    ProcData *procdata = static_cast<ProcData*>(data);
+    create_procproperties_dialog (procdata);
+}
+
 void
 cb_show_lsof(GtkAction *action, gpointer data)
 {
@@ -131,6 +155,8 @@ cb_show_lsof(GtkAction *action, gpointer data)
 void
 cb_about (GtkAction *action, gpointer data)
 {
+    ProcData *procdata = static_cast<ProcData*>(data);
+
     const gchar * const authors[] = {
         "Kevin Vandersloot",
         "Erik Johnsson",
@@ -138,6 +164,9 @@ cb_about (GtkAction *action, gpointer data)
         "Benoît Dejean",
         "Paolo Borelli",
         "Karl Lattimer",
+        "Perberos",
+        "Stefano Karapetsas",
+        "Steve Zesch",
         NULL
     };
 
@@ -153,21 +182,21 @@ cb_about (GtkAction *action, gpointer data)
     };
 
     gtk_show_about_dialog (
-        NULL,
-        "name",         _("System Monitor"),
-        "comments",     _("View current processes and monitor "
-                      "system state"),
-        "version",      VERSION,
-        "copyright",        "Copyright \xc2\xa9 2001-2004 Kevin Vandersloot\n"
-                    "Copyright \xc2\xa9 2005-2007 Benoît Dejean",
-        "logo-icon-name",   "utilities-system-monitor",
-        "authors",      authors,
-        "artists",      artists,
-        "documenters",      documenters,
-        "translator-credits",   _("translator-credits"),
-        "license",      "GPL 2+",
-        "wrap-license",     TRUE,
-        "website", "http://www.mate-desktop.org",
+        GTK_WINDOW (procdata->app),
+        "name",               _("System Monitor"),
+        "comments",           _("View current processes and monitor system state"),
+        "version",            VERSION,
+        "copyright",          "Copyright \xc2\xa9 2001-2004 Kevin Vandersloot\n"
+                              "Copyright \xc2\xa9 2005-2007 Benoît Dejean\n"
+                              "Copyright \xc2\xa9 2011-2014 MATE developers",
+        "logo-icon-name",     "utilities-system-monitor",
+        "authors",            authors,
+        "artists",            artists,
+        "documenters",        documenters,
+        "translator-credits", _("translator-credits"),
+        "license",            "GPL 2+",
+        "wrap-license",       TRUE,
+        "website",            "http://www.mate-desktop.org",
         NULL
         );
 }
@@ -176,11 +205,11 @@ cb_about (GtkAction *action, gpointer data)
 void
 cb_help_contents (GtkAction *action, gpointer data)
 {
-  GError* error = 0;
-  if (!g_app_info_launch_default_for_uri("ghelp:mate-system-monitor", NULL, &error)) {
-    g_warning("Could not display help : %s", error->message);
-    g_error_free(error);
-  }
+    GError* error = 0;
+    if (!g_app_info_launch_default_for_uri("help:mate-system-monitor", NULL, &error)) {
+        g_warning("Could not display help : %s", error->message);
+        g_error_free(error);
+    }
 }
 
 
@@ -288,13 +317,34 @@ cb_row_selected (GtkTreeSelection *selection, gpointer data)
 
     procdata->selection = selection;
 
+    procdata->selected_process = NULL;
+
     /* get the most recent selected process and determine if there are
     ** no selected processes
     */
     gtk_tree_selection_selected_foreach (procdata->selection, get_last_selected,
                          &procdata->selected_process);
+    if (procdata->selected_process) {
+        gint value;
+        gint nice = procdata->selected_process->nice;
+        if (nice < -7)
+            value = VERY_HIGH_PRIORITY;
+        else if (nice < -2)
+            value = HIGH_PRIORITY;
+        else if (nice < 3)
+            value = NORMAL_PRIORITY;
+        else if (nice < 7)
+            value = LOW_PRIORITY;
+        else
+            value = VERY_LOW_PRIORITY;
 
-        update_sensitivity(procdata);
+        GtkRadioAction* normal = GTK_RADIO_ACTION(gtk_action_group_get_action(procdata->action_group, "Normal"));
+        block_priority_changed_handlers(procdata, TRUE);
+        gtk_radio_action_set_current_value(normal, value);
+        block_priority_changed_handlers(procdata, FALSE);
+
+    }
+    update_sensitivity(procdata);
 }
 
 
